@@ -10,12 +10,15 @@ module Schleuder
 
     DEFAULTS = {
       'lists_dir' => '/var/lib/schleuder/lists',
+      'umask' => 0077,
       'listlogs_dir' => '/var/lib/schleuder/lists',
       'keyword_handlers_dir' => '/usr/local/lib/schleuder/keyword_handlers',
       'filters_dir' => '/usr/local/lib/schleuder/filters',
       'log_level' => 'warn',
       'superadmin' => 'root@localhost',
-      'keyserver' => 'hkp://pool.sks-keyservers.net',
+      'vks_keyserver' => 'https://keys.openpgp.org',
+      'sks_keyserver' => 'http://pool.sks-keyservers.net',
+      'http_proxy' => '',
       'smtp_settings' => {
         'address' => 'localhost',
         'port' => 25,
@@ -48,10 +51,19 @@ module Schleuder
       @config ||= load_config(ENV['SCHLEUDER_CONFIG'])
     end
 
+    def reload!
+      @config = nil
+      config
+    end
+
     def self.lists_dir
       instance.config['lists_dir']
     end
 
+    def self.umask
+      instance.config['umask']
+    end
+
     def self.listlogs_dir
       instance.config['listlogs_dir']
     end
@@ -115,8 +127,16 @@ module Schleuder
       settings
     end
 
-    def self.keyserver
-      instance.config['keyserver']
+    def self.vks_keyserver
+      instance.config['vks_keyserver']
+    end
+
+    def self.sks_keyserver
+      instance.config['sks_keyserver']
+    end
+
+    def self.http_proxy
+      instance.config['http_proxy']
     end
 
     private
