@@ -4,7 +4,7 @@ module Schleuder
       def initialize(list)
         set_default_locale
         super t('errors.decryption_failed',
-                    { key: list.key.to_s, email: list.sendkey_address })
+                    key: list.key.to_s, email: list.sendkey_address)
       end
     end
   end
