@@ -2,11 +2,7 @@ module Schleuder
   module Errors
     class KeywordAdminOnly < Base
       def initialize(keyword)
-        @keyword = keyword
-      end
-
-      def message
-        t('errors.keyword_admin_only', keyword: @keyword)
+        super t('errors.keyword_admin_only', keyword: keyword)
       end
     end
   end
