@@ -2,7 +2,7 @@ module Schleuder
   module Errors
     class TooManyKeys < Base
       def initialize(listdir, listname)
-        super t('errors.too_many_keys', {listdir: listdir, listname: listname})
+        super t('errors.too_many_keys', listdir: listdir, listname: listname)
       end
     end
   end
