@@ -1,11 +1,11 @@
-require "spec_helper"
+require 'spec_helper'
 
 describe Schleuder::LoggerNotifications do
   context 'return path' do
     it 'sets default superadmin' do
       list = create(:list, send_encrypted_only: false)
-      list.subscribe("schleuder@example.org", nil, true)
-      list.logger.notify_admin("Something", nil, I18n.t('notice'))
+      list.subscribe('schleuder@example.org', nil, true)
+      list.logger.notify_admin('Something', nil, I18n.t('notice'))
 
       message = Mail::TestMailer.deliveries.first
 
@@ -17,8 +17,8 @@ describe Schleuder::LoggerNotifications do
       oldval = Conf.instance.config['superadmin']
       Conf.instance.config['superadmin'] = 'schleuder-admin@example.org'
       list = create(:list, send_encrypted_only: false)
-      list.subscribe("schleuder@example.org", nil, true)
-      list.logger.notify_admin("Something", nil, I18n.t('notice'))
+      list.subscribe('schleuder@example.org', nil, true)
+      list.logger.notify_admin('Something', nil, I18n.t('notice'))
 
       message = Mail::TestMailer.deliveries.first
 
@@ -27,54 +27,54 @@ describe Schleuder::LoggerNotifications do
       Conf.instance.config['superadmin'] = oldval
     end
   end
-  it "notifies admins of simple text-message" do
+  it 'notifies admins of simple text-message' do
     list = create(:list, send_encrypted_only: false)
-    list.subscribe("schleuder@example.org", nil, true)
-    list.logger.notify_admin("Something", nil, I18n.t('notice'))
+    list.subscribe('schleuder@example.org', nil, true)
+    list.logger.notify_admin('Something', nil, I18n.t('notice'))
 
     message = Mail::TestMailer.deliveries.first
 
     expect(message.to).to eql(['schleuder@example.org'])
     expect(message.subject).to eql(I18n.t('notice'))
-    expect(message.first_plaintext_part.body.to_s).to eql("Something")
+    expect(message.first_plaintext_part.body.to_s).to eql('Something')
   end
 
-  it "notifies admins of multiple text-messages" do
+  it 'notifies admins of multiple text-messages' do
     list = create(:list, send_encrypted_only: false)
-    list.subscribe("schleuder@example.org", nil, true)
-    list.logger.notify_admin(["Something", "anotherthing"], nil, I18n.t('notice'))
+    list.subscribe('schleuder@example.org', nil, true)
+    list.logger.notify_admin(['Something', 'anotherthing'], nil, I18n.t('notice'))
 
     message = Mail::TestMailer.deliveries.first
 
     expect(message.to).to eql(['schleuder@example.org'])
     expect(message.subject).to eql(I18n.t('notice'))
-    expect(message.parts.first.parts.first.body.to_s).to eql("Something")
-    expect(message.parts.first.parts.last.body.to_s).to eql("anotherthing")
+    expect(message.parts.first.parts.first.body.to_s).to eql('Something')
+    expect(message.parts.first.parts.last.body.to_s).to eql('anotherthing')
   end
 
-  it "notifies admins of multiple text-messages and the original message" do
+  it 'notifies admins of multiple text-messages and the original message' do
     list = create(:list, send_encrypted_only: false)
-    list.subscribe("schleuder@example.org", nil, true)
+    list.subscribe('schleuder@example.org', nil, true)
     mail = Mail.new
-    mail.subject = "A subject"
-    list.logger.notify_admin(["Something", "anotherthing"], mail.to_s, I18n.t('notice'))
+    mail.subject = 'A subject'
+    list.logger.notify_admin(['Something', 'anotherthing'], mail.to_s, I18n.t('notice'))
 
     message = Mail::TestMailer.deliveries.first
 
     expect(message.to).to eql(['schleuder@example.org'])
     expect(message.subject).to eql(I18n.t('notice'))
-    expect(message.parts.first.parts.first.body.to_s).to eql("Something")
-    expect(message.parts.first.parts[1].body.to_s).to eql("anotherthing")
-    expect(message.parts.first.parts[2].body.to_s).to include("Subject: A subject")
-    expect(message.parts.first.parts[2][:content_type].content_type).to eql("message/rfc822")
+    expect(message.parts.first.parts.first.body.to_s).to eql('Something')
+    expect(message.parts.first.parts[1].body.to_s).to eql('anotherthing')
+    expect(message.parts.first.parts[2].body.to_s).to include('Subject: A subject')
+    expect(message.parts.first.parts[2][:content_type].content_type).to eql('message/rfc822')
   end
 
-  it "notifies admins encryptedly if their key is usable" do
+  it 'notifies admins encryptedly if their key is usable' do
     list = create(:list, send_encrypted_only: false)
-    list.subscribe("schleuder@example.org", '59C71FB38AEE22E091C78259D06350440F759BD3', true)
+    list.subscribe('schleuder@example.org', '59C71FB38AEE22E091C78259D06350440F759BD3', true)
     mail = Mail.new
-    mail.subject = "A subject"
-    list.logger.notify_admin(["Something", "anotherthing"], mail.to_s, I18n.t('notice'))
+    mail.subject = 'A subject'
+    list.logger.notify_admin(['Something', 'anotherthing'], mail.to_s, I18n.t('notice'))
 
     message = Mail::TestMailer.deliveries.first
 
@@ -83,13 +83,13 @@ describe Schleuder::LoggerNotifications do
     expect(message.parts.last.body.to_s).to include('-----BEGIN PGP MESSAGE-----')
   end
 
-  it "notifies admins in the clear if their key is unusable" do
+  it 'notifies admins in the clear if their key is unusable' do
     list = create(:list, send_encrypted_only: false)
-    key_material = File.read("spec/fixtures/partially_expired_key.txt")
-    list.subscribe("schleuder@example.org", nil, true, true, key_material)
+    key_material = File.read('spec/fixtures/partially_expired_key.txt')
+    list.subscribe('schleuder@example.org', nil, true, true, key_material)
     mail = Mail.new
-    mail.subject = "A subject"
-    list.logger.notify_admin("Something", mail.to_s, I18n.t('notice'))
+    mail.subject = 'A subject'
+    list.logger.notify_admin('Something', mail.to_s, I18n.t('notice'))
 
     message = Mail::TestMailer.deliveries.first
 
@@ -100,10 +100,10 @@ describe Schleuder::LoggerNotifications do
 
   it 'includes a List-Id header in notification mails sent to admins' do
     list = create(:list, send_encrypted_only: false)
-    list.subscribe("schleuder@example.org", nil, true)
+    list.subscribe('schleuder@example.org', nil, true)
 
     mail = Mail.new
-    list.logger.notify_admin("Something", mail.to_s, I18n.t('notice'))
+    list.logger.notify_admin('Something', mail.to_s, I18n.t('notice'))
 
     message = Mail::TestMailer.deliveries.first
 
